@@ -224,6 +224,7 @@ def test_trim_2D(random):
     node._X_train_indices = np.array(data.index.values, dtype=np.datetime64)
     start = np.datetime64('2018-01-01T00:00:05')
     stop = np.datetime64('2018-01-01T00:00:15')
+    node._dimensions = 2
     node._accumulate(start, stop)
     assert len(node._X_train_indices) == 10
     assert len(node._X_train) == 10
@@ -332,7 +333,7 @@ def test_fit_reset(caplog):
     node.i_events.data = make_event('reset')
     node.update()
     assert caplog.record_tuples[0][2] == 'Start training'
-    assert caplog.record_tuples[1][2].startswith('Reset')
+    assert caplog.record_tuples[1][2] == 'Reset'
     assert node._status == 0
 
 def test_receive_2D():
@@ -525,8 +526,10 @@ def test_predict_2D_output(random):
     node = Pipeline(steps=classifier, mode='fit_predict', meta_label=None)
     stream = DummyData(start_date=now())
     node.i.data = stream.next(5)
+    node.i.meta = {'foo': 'bar'}
     node.update()
     assert len(node.o_events.data) == 5
+    assert node.o_events.meta == node.i.meta
 
 def test_predict_3D_output():
     node = Pipeline(steps=dummy_classifier, mode='predict', meta_label='target')
@@ -540,17 +543,22 @@ def test_predict_3D_output():
         node.update()
     node.i_0.data = stream.next(5)
     node.i_1.data = stream.next(5)
+    node.i_0.meta = {'index': 0}
+    node.i_1.meta = {'index': 1}
     node.update()
     assert len(node.o_events.data) == 2
+    assert node.o_events.meta == {'epochs': [{'index': 0}, {'index': 1}]}
 
 def test_transform_2D_output(random):
     node = Pipeline(steps=dummy_transformer, mode='fit_transform')
     columns = ['A', 'B', 'C', 'D', 'E']
     node.i.data = DummyData(start_date=now()).next()
+    node.i.meta = {'foo': 'bar'}
     node.i.data.columns = columns
     node.update()
     assert np.array_equal(node.i.data.index.values, node.o.data.index.values)
     assert list(node.o.data.columns) == columns
+    assert node.o.meta == node.i.meta
 
 def test_transform_3D_output(random):
     pipeline = [
@@ -565,8 +573,12 @@ def test_transform_3D_output(random):
     node.i_1.data = stream.next()
     node.i_0.data.columns = columns
     node.i_1.data.columns = columns
+    node.i_0.meta = {'index': 0}
+    node.i_1.meta = {'index': 1}
     node.update()
     assert len(list(node.iterate('o_*'))) == 2
     assert np.array_equal(node.i_0.data.index.values, node.o_0.data.index.values)
     assert list(node.i_0.data.columns) == columns
     assert list(node.i_1.data.columns) == columns
+    assert node.o_0.meta == node.i_0.meta
+    assert node.o_1.meta == node.i_1.meta
